head

# XMLRésuméLibrary: User Guide

gpa | Element Reference | header

## Name

head —

Deprecated

## Synopsis

### Content Model

    (label,uri)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.4.0. It should not be used, and will be removed in a future version.

### Parents

`head` may be contained in these elements: `docpath`

## Examples

    <!-- TODO -->

gpa | Element Reference | header